==> core-react-0.8.0.tgz: package/es/Input/index.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import Icon from '../Icon';
import omit from '../_utils/omit';


function fixControlledValue(value) {
  return value || '';
}

var Input = /*#__PURE__*/function (_React$Component) {
  _inherits(Input, _React$Component);

  function Input(props) {
    var _this;

    _classCallCheck(this, Input);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(Input).call(this, props));

    _defineProperty(_assertThisInitialized(_this), "handleChange", function (e) {
      _this.props.onChange && _this.props.onChange(e);
    });

    _defineProperty(_assertThisInitialized(_this), "handleClear", function (e) {
      if (_this.props.onClear) {
        _this.props.onClear(e);

        _this.focus();
      }
    });

    _defineProperty(_assertThisInitialized(_this), "handleFocus", function (v) {
      _this.setState({
        focus: v
      });
    });

    _defineProperty(_assertThisInitialized(_this), "handleMouseEnter", function (v) {
      _this.setState({
        mouseEnter: v
      });
    });

    _this.input = React.createRef();
    _this.state = {
      focus: false,
      mouseEnter: false
    };
    return _this;
  }

  _createClass(Input, [{
    key: "focus",

    /**
     * @public
     * @name ref.current.focus
     * @description Same as HTMLInputElement.focus()
     */
    value: function focus() {
      this.input.current.focus();
    }
    /**
     * @public
     * @name ref.current.blur
     * @description Same as HTMLInputElement.blur()
     */

  }, {
    key: "blur",
    value: function blur() {
      this.input.current.blur();
    }
    /**
     * @public
     * @name ref.current.select
     * @description Same as HTMLInputElement.select()
     */

  }, {
    key: "select",
    value: function select() {
      this.input.current.select();
    }
  }, {
    key: "render",
    value: function render() {
      var _cx,
          _this2 = this;

      var _this$props = this.props,
          value = _this$props.value,
          className = _this$props.className,
          size = _this$props.size,
          width = _this$props.width,
          prefix = _this$props.prefix,
          suffix = _this$props.suffix,
          readonly = _this$props.readonly,
          onClear = _this$props.onClear,
          other = _objectWithoutProperties(_this$props, ["value", "className", "size", "width", "prefix", "suffix", "readonly", "onClear"]);

      var otherProps = omit(other, ['defaultValue', 'onChange']);
      var classNames = cx("".concat("waui", "-input"), (_cx = {}, _defineProperty(_cx, "".concat("waui", "-input--").concat(size), size), _defineProperty(_cx, "".concat("waui", "-input--prefix"), prefix), _defineProperty(_cx, "".concat("waui", "-input--suffix"), suffix || readonly || onClear), _cx), className);

      if (width) {
        otherProps.style = Object.assign(otherProps.style || {}, {
          width: width
        });
      }

      if (prefix || suffix) {
        return React.createElement("div", {
          className: "".concat("waui", "-input__affix-wrapper"),
          style: {
            width: width
          }
        }, prefix && React.createElement("span", {
          className: "".concat("waui", "-input__affix-wrapper--prefix")
        }, prefix), React.createElement("input", _extends({}, otherProps, {
          className: classNames,
          value: fixControlledValue(value),
          onChange: this.handleChange,
          ref: this.input
        })), suffix && React.createElement("span", {
          className: "".concat("waui", "-input__affix-wrapper--suffix")
        }, suffix));
      }

      if (readonly) {
        return React.createElement("div", {
          className: "".concat("waui", "-input__affix-wrapper"),
          style: {
            width: width
          }
        }, React.createElement("input", _extends({}, otherProps, {
          className: classNames,
          readOnly: readonly,
          value: fixControlledValue(value),
          onChange: this.handleChange,
          ref: this.input
        })), React.createElement("span", {
          className: "".concat("waui", "-input__affix-wrapper--suffix")
        }, React.createElement(Icon, {
          type: "locked"
        })));
      }

      if (onClear) {
        var _this$state = this.state,
            focus = _this$state.focus,
            mouseEnter = _this$state.mouseEnter;
        return React.createElement("div", {
          className: "".concat("waui", "-input__affix-wrapper"),
          style: {
            width: width
          },
          onMouseEnter: function onMouseEnter() {
            return _this2.handleMouseEnter(true);
          },
          onMouseLeave: function onMouseLeave() {
            return _this2.handleMouseEnter(false);
          }
        }, React.createElement("input", _extends({}, otherProps, {
          className: classNames,
          value: fixControlledValue(value),
          onChange: this.handleChange,
          onBlur: function onBlur() {
            return _this2.handleFocus(false);
          },
          onFocus: function onFocus() {
            return _this2.handleFocus(true);
          },
          ref: this.input
        })), value && (focus || mouseEnter) && !otherProps.disabled && React.createElement("span", {
          className: "".concat("waui", "-input__affix-wrapper--suffix")
        }, React.createElement(Icon, {
          type: "remove",
          onClick: this.handleClear
        })));
      }

      return React.createElement("input", _extends({}, otherProps, {
        className: classNames,
        value: fixControlledValue(value),
        onChange: this.handleChange,
        ref: this.input
      }));
    }
  }]);

  return Input;
}(React.Component);

Input.propTypes = {
  className: PropTypes.string,

  /** binding value */
  value: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),

  /** riggers when the icon inside Input value change */
  onChange: PropTypes.func,

  /** type of input, support [native input types](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/input#Form_%3Cinput%3E_types) */
  type: PropTypes.string,

  /** size of Input */
  size: PropTypes.oneOf(['sm', 'md', 'lg']),

  /** the length of input, unit as px */
  width: PropTypes.oneOfType([PropTypes.number, PropTypes.string]),

  /** whether Input is disabled */
  disabled: PropTypes.bool,

  /** whether Input is readonly */
  readonly: PropTypes.bool,

  /** same as native input placeholder */
  placeholder: PropTypes.string,

  /** the prefix icon for the Input */
  prefix: PropTypes.element,

  /** the suffix icon for the Input */
  suffix: PropTypes.element,

  /** triggers when the Input is cleared by clicking the clear button */
  onClear: PropTypes.func
};
Input.defaultProps = {
  width: '100%',
  size: 'md',
  type: 'text'
};
export default Input;

==> core-react-0.8.2.tgz: package/es/Input/index.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import Icon from '../Icon';
import omit from '../_utils/omit';


function fixControlledValue(value) {
  return value || '';
}

var Input = /*#__PURE__*/function (_React$Component) {
  _inherits(Input, _React$Component);

  function Input(props) {
    var _this;

    _classCallCheck(this, Input);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(Input).call(this, props));

    _defineProperty(_assertThisInitialized(_this), "handleChange", function (e) {
      _this.props.onChange && _this.props.onChange(e);
    });

    _defineProperty(_assertThisInitialized(_this), "handleClear", function (e) {
      if (_this.props.onClear) {
        _this.props.onClear(e);

        _this.focus();
      }
    });

    _defineProperty(_assertThisInitialized(_this), "handleFocus", function (v) {
      _this.setState({
        focus: v
      });
    });

    _defineProperty(_assertThisInitialized(_this), "handleMouseEnter", function (v) {
      _this.setState({
        mouseEnter: v
      });
    });

    _this.input = React.createRef();
    _this.state = {
      focus: false,
      mouseEnter: false
    };
    return _this;
  }

  _createClass(Input, [{
    key: "focus",

    /**
     * @public
     * @name ref.current.focus
     * @description Same as HTMLInputElement.focus()
     */
    value: function focus() {
      this.input.current.focus();
    }
    /**
     * @public
     * @name ref.current.blur
     * @description Same as HTMLInputElement.blur()
     */

  }, {
    key: "blur",
    value: function blur() {
      this.input.current.blur();
    }
    /**
     * @public
     * @name ref.current.select
     * @description Same as HTMLInputElement.select()
     */

  }, {
    key: "select",
    value: function select() {
      this.input.current.select();
    }
  }, {
    key: "render",
    value: function render() {
      var _cx,
          _this2 = this;

      var _this$props = this.props,
          value = _this$props.value,
          className = _this$props.className,
          size = _this$props.size,
          width = _this$props.width,
          prefix = _this$props.prefix,
          suffix = _this$props.suffix,
          readonly = _this$props.readonly,
          onClear = _this$props.onClear,
          other = _objectWithoutProperties(_this$props, ["value", "className", "size", "width", "prefix", "suffix", "readonly", "onClear"]);

      var otherProps = omit(other, ['defaultValue', 'onChange']);
      var classNames = cx("".concat("waui", "-input"), (_cx = {}, _defineProperty(_cx, "".concat("waui", "-input--").concat(size), size), _defineProperty(_cx, "".concat("waui", "-input--prefix"), prefix), _defineProperty(_cx, "".concat("waui", "-input--suffix"), suffix || readonly || onClear), _cx), className);

      if (width) {
        otherProps.style = Object.assign(otherProps.style || {}, {
          width: width
        });
      }

      if (prefix || suffix) {
        return (/*#__PURE__*/React.createElement("div", {
            className: "".concat("waui", "-input__affix-wrapper"),
            style: {
              width: width
            }
          }, prefix && /*#__PURE__*/React.createElement("span", {
            className: "".concat("waui", "-input__affix-wrapper--prefix")
          }, prefix), /*#__PURE__*/React.createElement("input", _extends({}, otherProps, {
            className: classNames,
            value: fixControlledValue(value),
            onChange: this.handleChange,
            ref: this.input
          })), suffix && /*#__PURE__*/React.createElement("span", {
            className: "".concat("waui", "-input__affix-wrapper--suffix")
          }, suffix))
        );
      }

      if (readonly) {
        return (/*#__PURE__*/React.createElement("div", {
            className: "".concat("waui", "-input__affix-wrapper"),
            style: {
              width: width
            }
          }, /*#__PURE__*/React.createElement("input", _extends({}, otherProps, {
            className: classNames,
            readOnly: readonly,
            value: fixControlledValue(value),
            onChange: this.handleChange,
            ref: this.input
          })), /*#__PURE__*/React.createElement("span", {
            className: "".concat("waui", "-input__affix-wrapper--suffix")
          }, /*#__PURE__*/React.createElement(Icon, {
            type: "locked"
          })))
        );
      }

      if (onClear) {
        var _this$state = this.state,
            focus = _this$state.focus,
            mouseEnter = _this$state.mouseEnter;
        return (/*#__PURE__*/React.createElement("div", {
            className: "".concat("waui", "-input__affix-wrapper"),
            style: {
              width: width
            },
            onMouseEnter: function onMouseEnter() {
              return _this2.handleMouseEnter(true);
            },
            onMouseLeave: function onMouseLeave() {
              return _this2.handleMouseEnter(false);
            }
          }, /*#__PURE__*/React.createElement("input", _extends({}, otherProps, {
            className: classNames,
            value: fixControlledValue(value),
            onChange: this.handleChange,
            onBlur: function onBlur() {
              return _this2.handleFocus(false);
            },
            onFocus: function onFocus() {
              return _this2.handleFocus(true);
            },
            ref: this.input
          })), value && (focus || mouseEnter) && !otherProps.disabled && /*#__PURE__*/React.createElement("span", {
            className: "".concat("waui", "-input__affix-wrapper--suffix")
          }, /*#__PURE__*/React.createElement(Icon, {
            type: "remove",
            onClick: this.handleClear
          })))
        );
      }

      return (/*#__PURE__*/React.createElement("input", _extends({}, otherProps, {
          className: classNames,
          value: fixControlledValue(value),
          onChange: this.handleChange,
          ref: this.input
        }))
      );
    }
  }]);

  return Input;
}(React.Component);

Input.propTypes = {
  className: PropTypes.string,

  /** binding value */
  value: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),

  /** riggers when the icon inside Input value change */
  onChange: PropTypes.func,

  /** type of input, support [native input types](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/input#Form_%3Cinput%3E_types) */
  type: PropTypes.string,

  /** size of Input */
  size: PropTypes.oneOf(['sm', 'md', 'lg']),

  /** the length of input, unit as px */
  width: PropTypes.oneOfType([PropTypes.number, PropTypes.string]),

  /** whether Input is disabled */
  disabled: PropTypes.bool,

  /** whether Input is readonly */
  readonly: PropTypes.bool,

  /** same as native input placeholder */
  placeholder: PropTypes.string,

  /** the prefix icon for the Input */
  prefix: PropTypes.element,

  /** the suffix icon for the Input */
  suffix: PropTypes.element,

  /** triggers when the Input is cleared by clicking the clear button */
  onClear: PropTypes.func
};
Input.defaultProps = {
  width: '100%',
  size: 'md',
  type: 'text'
};
export default Input;
